@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
-import nltk
-from nltk.tag import pos_tag as nltk_tag
+from .packages import nltk
 from .en import tag as pattern_tag
+from .exceptions import MissingCorpusException
 
 class BaseTagger(object):
 
@@ -37,6 +37,10 @@ class NLTKTagger(BaseTagger):
     def tag(self, sentence, tokenize=True):
         if tokenize:
             sentence = nltk.tokenize.word_tokenize(sentence)
-        return nltk_tag(sentence)
+        try:
+            tagged = nltk.tag.pos_tag(sentence)
+        except LookupError:
+            raise MissingCorpusException()
+        return tagged
 
 
